Package 'energyGOF'

Title: Goodness-of-Fit Tests for Univariate Data via Energy
Description: Conduct one- and two-sample goodness-of-fit tests for univariate data. In the one-sample case, normal, uniform, exponential, Bernoulli, binomial, geometric, beta, Poisson, lognormal, Laplace, asymmetric Laplace, inverse Gaussian, half-normal, chi-squared, gamma, F, Weibull, Cauchy, and Pareto distributions are supported. egof.test() can also test goodness-of-fit to any distribution with a continuous distribution function. A subset of the available distributions can be tested for the composite goodness-of-fit hypothesis, that is, one can test for distribution fit with unknown parameters. P-values are calculated via parametric bootstrap.
Authors: John Haman [aut, cre]
Maintainer: John Haman <[email protected]>
License: GPL (>= 3)
Version: 0.1
Built: 2026-05-12 19:48:27 UTC
Source: https://github.com/jthaman/energygof

Help Index